@@ -1,6 +1,8 @@
 'A simple class for loading and playing sounds and music'
 import pygame
 from pathlib import Path
+from errno import ENOENT as _ENOENT
+from os import strerror as _strerror
 
 class Sounds:
 	'''A class for playing sounds or music
@@ -36,7 +38,7 @@ class Sounds:
 	def add_sound(self, path, name, volume=-1):
 		'''Adding sounds to the Sounds dictionary
 		The volume will be set by the volume variable if volume is -1'''
-		self.sounds[name] = pygame.mixer.Sound(Path(path).resolve())
+		self.sounds[name] = pygame.mixer.Sound(f'{Path(path).resolve()}')
 		self.sounds[name].set_volume(self.volume if volume == -1 else volume)
 
 	def set_play_sound(self, play_sound_boolean, affect_music=True):
@@ -75,7 +77,10 @@ class Sounds:
 		'''This will play the music file if play_sound_variable is True
 		The volume will be the volume variable if volume is -1
 		amount is the amount of times played, it will be indefinitely if amount is -1'''
+		path = Path(path).resolve()
+		if not path.is_file():
+			raise FileNotFoundError(_ENOENT, _strerror(_ENOENT), f'{path}')
 		if self.play_sound_variable:
-			pygame.mixer.music.load(Path(path).resolve())
+			pygame.mixer.music.load(path)
 			pygame.mixer.music.set_volume(self.volume if volume == -1 else volume)
 			pygame.mixer.music.play(amount)
\ No newline at end of file
